@@ -28,6 +28,7 @@
     if (!is.null(fixed)) {
         stopifnot(all(names(fixed) %in% colnames(Y)))
         fix <- colnames(Y) %in% names(fixed)
+        fixed <- fixed[colnames(Y)[fix]]
         ui <- ui[,!fix,drop = FALSE]
         .parm <- function(beta) {
             nm <- names(beta)
@@ -267,6 +268,7 @@
     if (!is.null(fixed)) {
         stopifnot(all(names(fixed) %in% colnames(Y)))
         fix <- colnames(Y) %in% names(fixed)
+        fixed <- fixed[colnames(Y)[fix]]
         ui <- ui[,!fix,drop = FALSE]
     } else {
         fix <- rep(FALSE, ncol(Y))
@@ -307,7 +309,11 @@
     }
 
     if (!is.null(ui)) {    
-        ret <- c(coneproj::qprog(Dmat, dvec, ui, ci, msg = FALSE)$thetahat)
+        ret <- try(c(coneproj::qprog(Dmat, dvec, ui, ci, msg = FALSE)$thetahat))
+        if (inherits(ret, "try-error")) {
+            diag(Dmat) <- diag(Dmat) + 1e-3
+            ret <- c(coneproj::qprog(Dmat, dvec, ui, ci, msg = FALSE)$thetahat)
+        }
         ### was: solve.QP(Dmat, dvec, t(ui), ci, meq = 0)$solution
     } else {
         ret <- lm.fit(x = X, y = Z)$coef
@@ -346,9 +352,15 @@ mlt <- function(model, data, weights = NULL, offset = NULL, fixed = NULL,
     vars <- as.vars(model)
     response <- variable.names(model, "response")
     responsevar <- vars[[response]]
+    ### <FIXME>: how can we check Surv objects?
+    if (!inherits(data[[response]], "Surv"))
+        stopifnot(check(responsevar, data))
+    ### </FIXME>
     bounds <- bounds(responsevar)
     stopifnot(length(response) == 1)
+    ### <FIXME> add bounds?
     y <- R(object = data[[response]])
+    ### </FIXME>
 
     if (!.checkR(y, weights)) dofit <- FALSE
 
